@@ -4,7 +4,7 @@ import argparse
 from llama_cpp import Llama
 
 parser = argparse.ArgumentParser()
-parser.add_argument("-m", "--model", type=str, default="./models/...")
+parser.add_argument("-m", "--model", type=str, default="../models/7B/ggml-models.bin")
 args = parser.parse_args()
 
 llm = Llama(model_path=args.model)
